"""Version information for jBOM"""

__version__ = "6.0.0"
__version_info__ = (3, 6, 0)

__title__ = "jbom"
__description__ = (
    "Intelligent KiCad Bill of Materials generator with inventory matching"
)
__author__ = "John Plocher"
__author_email__ = "John.Plocher@gmail.com"
__license__ = "AGPLv3"
__url__ = "https://github.com/SPCoast/jBOM"
